"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const unified_lint_rule_1 = __importDefault(require("unified-lint-rule"));
const gray_matter_1 = __importDefault(require("gray-matter"));
const ajv_1 = __importDefault(require("ajv"));
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
// JSON schema for front-matter validation
const playgroundExampleSchema = {
    type: 'object',
    properties: {
        examples: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    label: { type: 'string' },
                    description: { type: 'string' },
                },
                required: ['name', 'label', 'description'],
                additionalProperties: false,
            },
        },
    },
    required: ['examples'],
};
const ajv = new ajv_1.default();
const validateSchema = ajv.compile(playgroundExampleSchema);
function checkForExampleFolder(node, file, examples, cwd) {
    const fileDirectory = path_1.default.resolve(file.path ? path_1.default.dirname(file.path) : cwd);
    const examplesDirectory = path_1.default.join(fileDirectory, 'examples');
    // Check if specific files exist based on front matter content
    examples.forEach((example) => {
        const folderName = example.name;
        const folderPath = path_1.default.join(examplesDirectory, folderName);
        try {
            if (!fs_1.default.existsSync(folderPath)) {
                file.message(`Folder '${folderName}' is missing but referenced in the playground example front matter.`, node);
                return;
            }
            const filesInExampleDir = fs_1.default.readdirSync(folderPath);
            if (filesInExampleDir.length === 0) {
                file.message(`Folder '${folderPath}' is empty. Add the respective example files.`, node);
            }
        }
        catch (err) {
            file.message(`Error checking example folder: '${folderPath}'`);
        }
    });
}
function validateFrontMatterInMarkdown(tree, file, cwd) {
    (0, unist_util_visit_1.default)(tree, ['yaml'], (node) => {
        const fileContent = file.toString();
        //Reg-ex to check if the example front matter exists or no.
        const frontMatterMatch = fileContent.match(/---\n([\s\S]+?)\n---/);
        if (!frontMatterMatch) {
            return;
        }
        const { data } = (0, gray_matter_1.default)(fileContent);
        if (!validateSchema(data)) {
            file.message(`Playground example front matter is invalid.`, node);
            return;
        }
        checkForExampleFolder(node, file, data === null || data === void 0 ? void 0 : data.examples, cwd);
    });
}
module.exports = (0, unified_lint_rule_1.default)('sfdocs-lint:remark-lint-markdown-frontmatter-playground', validateFrontMatterInMarkdown);
//# sourceMappingURL=index.js.map